#
# spec file for package containment-rpm
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           containment-rpm
Version:        2.0.2
Release:        1.5
Summary:        Wraps OBS docker/kiwi-built images in rpms
License:        MIT
Group:          System/Management
URL:            https://github.com/SUSE/containment-rpm-docker
Source:         https://github.com/SUSE/containment-rpm/archive/refs/tags/v%{version}.tar.gz
BuildRequires:  filesystem
Requires:       jq
Requires:       libxml2-tools
BuildArch:      noarch
# disabled for now, not used for public cloud purpose
%if 0
Requires:       changelog-generator-data
Requires:       libxml2-tools
%if 0%{?suse_version} >= 1230
Requires:       rubygem(changelog_generator)
%else
Requires:       rubygem-changelog_generator
%endif
%endif

%description
OBS container_post_run hook to wrap a kiwi or docker image in an rpm package.

This package should be required by the Build Service project's meta
prjconf, so that the container_post_run hook is present in the container image
and gets executed at the end of the image build.  It will then build
an rpm which contains the newly-produced image from kiwi/docker (using
image.spec.in), and place the rpm in the correct location that it
becomes an additional build artefact.

%prep
%setup -q

%build

%install
mkdir -p %{buildroot}%{_prefix}/lib/build/post_build.d
install -m 644 image.spec.in %{buildroot}%{_prefix}/lib/build/
install -m 755 container_post_run %{buildroot}%{_prefix}/lib/build/post_build.d/

%files
%dir %{_prefix}/lib/build/post_build.d
%{_prefix}/lib/build/post_build.d/*_post_run
%{_prefix}/lib/build/image.spec.in

%changelog
* Fri Oct 27 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.2:
  * Handle better container name from kiwi
* Wed Sep 20 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.1:
  * More robust handling of tags
* Tue Apr  4 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.0:
  * to Use uname -m for ARCH and also pass to rpmbuild
  * Fix plural on sentence by
  * adapt kiwi hook to new obs-build one and expand for docker build
* Tue Jun 12 2018 containers-builds@suse.de
- Commit 4532982 by Sergio Lindo Mansilla SLindoMansilla@suse.com
  Fix plural on sentence
* Thu Jun  7 2018 containers-builds@suse.de
- Commit 97bf8fc by Fabian Vogt fvogt@suse.com
  Use uname -m for ARCH and also pass to rpmbuild
  Otherwise we get into a mess where i386/i586/i686 are used in place of each
  other.
  Fixes #35
* Mon May 14 2018 containers-bugowner@suse.de
- Commit fec546a by Jordi Massaguer Pla jmassaguerpla@suse.de
  recommend changelog generator data instead of requiring it
  Using the changelog generator data is not a hard requirement. You can build
  rpms containing containers without creating the changelogs.
  This way, it will create the changelogs only if the changelog-generator-data
  package is available
  Signed-off-by: Jordi Massaguer Pla <jmassaguerpla@suse.de>
* Wed Mar 28 2018 containers-bugowner@suse.de
- Commit c2e30cc by David Cassany dcassany@suse.com
  Make local builds possible
  This commit makes local OBS builds of images wrapped in RPMs possible.
* Mon Mar  5 2018 containers-bugowner@suse.de
- Commit 229b3d2 by Fabian Vogt fvogt@suse.com
  Abort build if changelog found but changelog-generator not available
  Commit 8af17f6 by Fabian Vogt fabian@ritter-vogt.de
  Make changelog-generator optional for openSUSE
  Fixes #31
  feature#openSUSE_Kubic
* Fri Feb  2 2018 containers-bugowner@suse.de
- Commit 1956b4f by Jordi Massaguer Pla jmassaguerpla@suse.de
  Add conflicts with other packages that provide the same hook
  /usr/lib/build/kiwi_post_run
  Signed-off-by: Jordi Massaguer Pla <jmassaguerpla@suse.de>
* Mon Jan 15 2018 containers-bugowner@suse.de
- Commit 56cf72d by David Cassany dcassany@suse.com
  Exit if no tag defined
  This commit exits the kiwi_post_run hook script in case the config.xml file
  does not include any tag specification.
* Wed Nov  8 2017 containers-bugowner@suse.de
- Commit c3c1362 by Flavio Castelli fcastelli@suse.com
  Obsolete packages with older naming scheme [bsc#1066653]
  Ensure the packages that followed the older naming scheme get replaced by the
  new ones.
  Signed-off-by: Flavio Castelli <fcastelli@suse.com>
* Wed Sep  6 2017 containers-bugowner@suse.de
- Commit 66d6869 by David Cassany dcassany@suse.com
  This commit removed the word 'docker' from the package name
* Fri Sep  1 2017 containers-bugowner@suse.de
- Commit 055de6e by Jordi Massaguer Pla jmassaguerpla@suse.de
  Use IBS build number to distinguish releases
  This solves a number of problems around updating images within IBS, and
  delivering those as updates.
  This is a rebase from https://github.com/SUSE/containment-rpm-docker/pull/24
  Which Kiall started
* Mon Aug 28 2017 containers-bugowner@suse.de
- Commit 055de6e by Jordi Massaguer Pla jmassaguerpla@suse.de
  Use IBS build number to distinguish releases
  This solves a number of problems around updating images within IBS, and
  delivering those as updates.
  This is a rebase from https://github.com/SUSE/containment-rpm-docker/pull/24
  Which Kiall started
* Wed Aug 23 2017 containers-bugowner@suse.de
- Commit 1a6b95f by Kiall Mac Innes kiall@macinnes.ie
  Add a tagfile, a mechanism to determine the latest image
  Sometimes, using a ":latest" tag is not enough, for example, when you need to
  inform Kubernetes that it should perform a rolling upgrade to the new tag.
  By adding a file which contains the most specific tag for a given image, we
  can have downstream tools use this to determine the tag that matches the
  currently installed RPM.
* Mon Aug  7 2017 containers-bugowner@suse.de
- Commit 01528cd by David Cassany dcassany@suse.com
  Add DISTURL in RPM metadata, fixes bsc#1052030
  With this commit kiwi_post_run script reads the '/.build/build.data' file
  from the build service environment in order to get the $DISTURL environment
  variable and set the DISTURL value in the rpm.
* Fri Jul 28 2017 containers-bugowner@suse.de
- Commit 593eaf5 by Maximilian Meister mmeister@suse.de
  make branch safe by transforming slashes to dashes
  Signed-off-by: Maximilian Meister <mmeister@suse.de>
  Commit 2ba6987 by Maximilian Meister mmeister@suse.de
  packaging: make branch configurable
  Signed-off-by: Maximilian Meister <mmeister@suse.de>
* Fri Jun 30 2017 containers-bugowner@suse.de
- Commit d0c508a by David Cassany dcassany@suse.com
  Remove tag from the package name
  Now the image tag can be updated without creating a different rpm package for
  each update.
  This commit fixes bsc#1046378.
* Tue Jun 13 2017 containers-bugowner@suse.de
- Commit b094d74 by Jordi Massaguer Pla jmassaguerpla@suse.de
  add make_spec.sh script to create the spec file
  otherwise, we had to update the version in the containment-rpm-docker and,
  since this can be forgotten, we could end up with packages version 1.3.4 but
  having master code in it which contains extra commits
* Mon Jun 12 2017 containers-bugowner@suse.de
- Commit 145d37c by Jordi Massaguer Pla jmassaguerpla@suse.de
  review filenames
  use old.[packages|changes].$PKG_NAME.$ARCH instead, because this is all start
  with old. This is just cosmetic but it is how we are doing it in the kubik
  project.
  Also fix the "if" clauses which were checking for the file existance which
  were looking in the wrong path
* Wed May 31 2017 containers-bugowner@suse.de
- Commit db142fc by David Cassany dcassany@suse.com
  Include symlink to the image with a simplified name
  This commit includes in the resulting docker image RPM a symlink to the image
  tarball that does not include any version number, arch and extension. The
  symlink is named as it is in the `name` attribute of the `image` tag within
  the kiwi description file. This way the base image version can be updated
  without having to also update base image reference inside the derived image
  kiwi description file.
  Related to bsc#1038192
* Fri May 26 2017 containers-bugowner@suse.de
- Commit 53d931e by Jordi Massaguer Pla jmassaguerpla@suse.de
  remove sle2docker recommendation. fixes bsc#1032663
* Thu May 25 2017 containers-bugowner@suse.de
- Commit c36be37 by Jordi Massaguer Pla jmassaguerpla@suse.de
  fix typo in filename
  Signed-off-by: Jordi Massaguer Pla <jmassaguerpla@suse.de>
* Thu May 25 2017 containers-bugowner@suse.de
- Commit 74c13c4 by Jordi Massaguer Pla jmassaguerpla@suse.de
- check if old.changes and old.packages exist and otherwise create an empty
- images.changes
* Thu May 25 2017 containers-bugowner@suse.de
- Commit 2aa7744 by Jordi Massaguer Pla jmassaguerpla@suse.de
  multi packages in one repo
  add the package name as a prefix in the old.packages and old.changelog:
  $PKG_NAME.old.packages.$ARCH
  $PKG_NAME.old.changelog.$ARCH
  this way, if we have more than one docker image in the same obs repo, this
  script will only take the old files for the right package.
  Signed-off-by: Jordi Massaguer Pla <jmassaguerpla@suse.de>
* Tue Mar 21 2017 containers-bugowner@suse.de
- packaging: fix path within archive
* Tue Mar 21 2017 containers-bugowner@suse.de
- change compression format to gzip
* Tue Mar 21 2017 containers-bugowner@suse.de
- change compression format to gzip
* Mon Mar 20 2017 mmeister@suse.com
- synchronize specfile with git versioned specfile from
  https://github.com/SUSE/containment-rpm-docker
* Thu Mar 16 2017 mjura@suse.com
- Updated to version 1.3.4
  - change installation path for images
  - generate metadata file with Docker image information
* Fri Mar 10 2017 mjura@suse.com
- Update to version 1.3.3
  - rename KIWI image files before building the package
  - add libxml2-tools package to runtime requirements
  - parse KIWI config.xml and fetch containers metadata
  - added openSUSE as possible image name
* Thu Nov 12 2015 fcastelli@suse.com
- Update to version 1.2.0:
  - change the OBS script to look for changelong and old packages files
    according to the target architecture
* Tue Jul 14 2015 fcastelli@suse.com
- Fix rubygem-changelog-generator requirement according to the OS
  version
* Wed Apr 22 2015 ro@suse.de
- require changelog-generator-data
* Wed Apr 22 2015 ro@suse.de
- require rubygem-changelog_generator
* Wed Apr  1 2015 fcastelli@suse.com
- Version 1.1.0:
  * automatic generation of the changelog
  * recommend the installation of sle2docker
* Thu Mar 19 2015 fcastelli@suse.com
- Created initial version
